@@ -18,10 +18,13 @@ pub struct Output {
     pub output_type: String,
     pub data: Option<Data>,
     pub text: Option<Vec<String>>,
+    pub traceback: Option<Vec<String>>,
 }
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct Data {
     #[serde(rename(serialize = "text/plain", deserialize = "text/plain"))]
     pub text_plain: Option<Vec<String>>,
+    #[serde(rename(serialize = "image/png", deserialize = "image/png"))]
+    pub image_png: Option<String>,
 }
